@@ -1,17 +1,11 @@
 package Data::ModeMerge::Mode::ADD;
-BEGIN {
-  $Data::ModeMerge::Mode::ADD::VERSION = '0.27';
-}
-# ABSTRACT: Handler for Data::ModeMerge ADD merge mode
-
 
 use 5.010;
-use strict;
-use warnings;
-
 use Moo;
 extends 'Data::ModeMerge::Mode::NORMAL';
 
+our $VERSION = '0.28'; # VERSION
+
 sub name { 'ADD' }
 
 sub precedence_level { 3 }
@@ -67,6 +61,8 @@ sub merge_HASH_ARRAY {
 }
 
 1;
+# ABSTRACT: Handler for Data::ModeMerge ADD merge mode
+
 
 __END__
 =pod
@@ -77,11 +73,11 @@ Data::ModeMerge::Mode::ADD - Handler for Data::ModeMerge ADD merge mode
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
-    use Data::ModeMerge;
+ use Data::ModeMerge;
 
 =head1 DESCRIPTION
 
@@ -95,7 +91,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
