@@ -1,17 +1,11 @@
 package Data::ModeMerge::Mode::CONCAT;
-BEGIN {
-  $Data::ModeMerge::Mode::CONCAT::VERSION = '0.27';
-}
-# ABSTRACT: Handler for Data::ModeMerge CONCAT merge mode
-
 
 use 5.010;
-use strict;
-use warnings;
-
 use Moo;
 extends 'Data::ModeMerge::Mode::ADD';
 
+our $VERSION = '0.28'; # VERSION
+
 sub name { 'CONCAT' }
 
 sub precedence_level { 2 }
@@ -26,6 +20,8 @@ sub merge_SCALAR_SCALAR {
 }
 
 1;
+# ABSTRACT: Handler for Data::ModeMerge CONCAT merge mode
+
 
 __END__
 =pod
@@ -36,11 +32,11 @@ Data::ModeMerge::Mode::CONCAT - Handler for Data::ModeMerge CONCAT merge mode
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
-    use Data::ModeMerge;
+ use Data::ModeMerge;
 
 =head1 DESCRIPTION
 
@@ -54,7 +50,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
