@@ -1,17 +1,11 @@
 package Data::ModeMerge::Mode::KEEP;
-BEGIN {
-  $Data::ModeMerge::Mode::KEEP::VERSION = '0.27';
-}
-# ABSTRACT: Handler for Data::ModeMerge KEEP merge mode
-
 
 use 5.010;
-use strict;
-use warnings;
-
 use Moo;
 extends 'Data::ModeMerge::Mode::Base';
 
+our $VERSION = '0.28'; # VERSION
+
 sub name { 'KEEP' }
 
 sub precedence_level { 6 }
@@ -66,6 +60,9 @@ sub merge_HASH_HASH {
 };
 
 1;
+# ABSTRACT: Handler for Data::ModeMerge KEEP merge mode
+
+
 
 __END__
 =pod
@@ -76,11 +73,11 @@ Data::ModeMerge::Mode::KEEP - Handler for Data::ModeMerge KEEP merge mode
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
-    use Data::ModeMerge;
+ use Data::ModeMerge;
 
 =head1 DESCRIPTION
 
@@ -94,7 +91,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
