@@ -1,17 +1,11 @@
 package Data::ModeMerge::Mode::SUBTRACT;
-BEGIN {
-  $Data::ModeMerge::Mode::SUBTRACT::VERSION = '0.27';
-}
-# ABSTRACT: Handler for Data::ModeMerge SUBTRACT merge mode
-
 
 use 5.010;
-use strict;
-use warnings;
-
 use Moo;
 extends 'Data::ModeMerge::Mode::NORMAL';
 
+our $VERSION = '0.28'; # VERSION
+
 sub name { 'SUBTRACT' }
 
 sub precedence_level { 4 }
@@ -90,6 +84,8 @@ sub merge_HASH_HASH {
 }
 
 1;
+# ABSTRACT: Handler for Data::ModeMerge SUBTRACT merge mode
+
 
 __END__
 =pod
@@ -100,11 +96,11 @@ Data::ModeMerge::Mode::SUBTRACT - Handler for Data::ModeMerge SUBTRACT merge mod
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
-    use Data::ModeMerge;
+ use Data::ModeMerge;
 
 =head1 DESCRIPTION
 
@@ -118,7 +114,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Steven Haryanto.
+This software is copyright (c) 2012 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
